@@ -3,15 +3,22 @@ from __future__ import print_function, unicode_literals
 import sys
 import platform
 from pyfiglet import Figlet
-from PyInquirer import style_from_dict, Token, prompt
 
 from Alexandria.general.console import print_color
 
-from anchorage import anchor_online, anchor_locally, path, load
+from anchorage import anchor_online, anchor_locally, bookmarks, path, load
 from anchor_infrs.infrastructure import init
 from anchor_infrs.system import operating_system
 from anchor_infrs.shell import shell
 
+try:
+    from PyInquirer import style_from_dict, Token, prompt
+except ImportError:
+    print("PyInquirer import error: prompt-toolkits version != 1.0.14")
+    print("Installing prompt-toolkit==1.0.14")
+    shell("pip install prompt-toolkit==1.0.14")
+    sys.exit("Success! Please run again")
+
 
 def smart_print_color(text, color, **kwargs):
     if operating_system() in ["linux", "macos"]:
@@ -86,10 +93,10 @@ def interface():
         sys.exit()
 
     print("  ~~Running dependency checks")
-    shell("pip3 install --upgrade anchorage")
+    # shell("pip3 install --upgrade anchorage")
     init()
     print("  ~~Everything in order!")
-    smart_print_color("  ~~Edit settings in ~/.anchorage/config.toml", "green")
+    smart_print_color("  ~~Edit settings in ~/.anchorage/config.toml", "blue")
 
     # 2. Browser choice
     brow_choice = [{
@@ -135,21 +142,52 @@ def interface():
             'default': True
         }]
         if prompt(chrmm_check, style=style)['correctPath']:
-            bmk = load(path(browser))
+            bmk_dict = load(path(browser))
         else:
-            bmk = load(path(prompt(chrmm_path, style=style)['correctPath']))
+            bmk_dict = load(path(prompt(chrmm_path, style=style)['correctPath']))
     elif browser == "firefox":
-        bmk = load(prompt(firefx_path, style=style)['path'])
+        bmk_dict = load(prompt(firefx_path, style=style)['path'])
     else:
-        bmk = load(prompt(custom_path, style=style)['path'])
+        bmk_dict = load(prompt(custom_path, style=style)['path'])
+
+    # 5. Bookmark filter
+    #     - Exclude local files
+    #     - Exclude certain directories
+    #     - Exclude bookmarks with given strings within their names
+    #     - Exclude bookmarks with given strings within their links
+    bk_filt = [{
+                    'type': 'checkbox',
+                    'name': 'drop',
+                    'message': f'If desired, specify which elements to exclude from the archiving process.',
+                    'choices': [
+                        {
+                            'name': 'Local files'
+                        },
+                        {
+                            'name': 'Directories'
+                        },
+                        {
+                            'name': 'Terms in URL'
+                        },
+                        {
+                            'name': 'Terms in name'
+                        },
+                    ],
+                    'filter': lambda n: n.lower() if isinstance(n, str) else n
+                }]
+    drop_dirs = [{
+                      'type': 'input',
+                      'name': 'dirs',
+                      'message': 'Please write a comma-separated ',
+                      'default': ''
+                   }]
+
+    drop_list = prompt(custom_path, style=style)['drop']
+
+    bmk = bookmarks(bmk_dict,
+                    drop_local_files=True if 'local files' in drop_list else False,
+                    )
 
-#     # 5. Bookmark filter
-#     #     - Exclude local files
-#     #     - Exclude certain directories
-#     #     - Exclude bookmarks with given strings within their names
-#     #     - Exclude bookmarks with given strings within their links
-#     bk_filt = []
-#     prompt(bk_filt, style=style)
 #     # 6. Local or online archive
 #     archive = []
 #     prompt(archive, style=style)
@@ -232,4 +270,4 @@ def interface():
 #         }
 #     ]
 
-interface()
+# interface()
