@@ -66,6 +66,12 @@ class bookmarks:
                  drop_local_files=True,
                  drop_duplicate_urls=True,
                  drop_directories=None,
+                 drop_dir_if_contains=None,
+                 drop_url_if_contains=None,
+                 drop_name_if_contains=None,
+                 drop_dir_regex=None,
+                 drop_url_regex=None,
+                 drop_name_regex=None,
                  ):
         """
         Prepare bookmarks for archiving.
